function [year, radius, xH, yH, velocity] = read_Horizons(firstyear, lastyear)
%
%  Sverre Holm, Univ Oslo 19 May 2012
%
%
% read data for sun barycenter from JPL Horizons data
filename = 'data/horizons_results-4811intervals.txt'; % 
lls = 52;

%
% data generated by JPL Horizons system, equal-step sampling 1850-2010
% info in file 'horizons_results-1932steps.txt' and 'HORIZONS-1932steps.pdf'
%
% units: Julian Date, km and km/s
%
fileID = fopen(filename);

% skip first 52/57 lines of text
for ll=1:lls, 
    fgets(fileID); 
end


data = zeros(7,4812);
for nr = 1:length(data)
    data(1,nr) = fscanf(fileID,'%f',[1 1]); % read first number on first line
    fgets(fileID);  % get rest of data and skip to next line
    data(2:4,nr) = fscanf(fileID,'  %e%e%e',[3 1]);  % position
    data(5:7,nr) = fscanf(fileID,'  %e%e%e',[3 1]);  % velocity
end

fclose(fileID);

nrdata    = length(data);
%
% one sample per month on average
% 
radiusSun = 1.392e9/2; % Mean radius, meters, http://en.wikipedia.org/wiki/Sun

% jd2yr has numerical problems - many values of year will be the same
% year      = jd2yr(data(1,:)); % convert from Julian date to year
%
%  datestr(data(1,1:10) + 678942-2400000.5)  
%  from Matlab day to modified Julian Date: 678942; from JD to MJD: -2400000.5
%  JD: ref  12:00 January 1, 4713 BC, Monday
%  MJD: ref 00:00 November 17, 1858, Wednesday
%
% from http://home.online.no/~pjacklam/matlab/software/util/timeutil/index.html
[yr, month, day, hour, minute, second] = jd2date(data(1,:));
year      = yearnum(yr, month, day, hour, minute, second);

radius    = 1000*sqrt(data(2,:).^2 + data(3,:).^2 + data(4,:).^2)/radiusSun;
xH        = 1000*data(2,:)/radiusSun;
yH        = 1000*data(3,:)/radiusSun;
velocity  = 1000*sqrt(data(5,:).^2 + data(6,:).^2 + data(7,:).^2); % m/s


% truncate dataset if required

if firstyear > year(1)
    indx = find(year >= firstyear);
    year = year(indx);
    radius = radius(indx);
    xH = xH(indx);
    yH = yH(indx);
    velocity = velocity(indx); 
end

if lastyear < year(length(year))
    indx = find(year <= lastyear);
    year = year(indx);
    radius = radius(indx);
    xH = xH(indx);
    yH = yH(indx);
    velocity = velocity(indx);
end


return